@@ -1,16 +1,19 @@
-{-# LANGUAGE DeriveFoldable    #-}
-{-# LANGUAGE DeriveFunctor     #-}
-{-# LANGUAGE DeriveTraversable #-}
-{-# LANGUAGE EmptyDataDecls    #-}
-{-# LANGUAGE FlexibleInstances #-}
+{-# LANGUAGE DeriveDataTypeable #-}
+{-# LANGUAGE DeriveFoldable     #-}
+{-# LANGUAGE DeriveFunctor      #-}
+{-# LANGUAGE DeriveTraversable  #-}
+{-# LANGUAGE EmptyDataDecls     #-}
+{-# LANGUAGE FlexibleInstances  #-}
+{-# OPTIONS_GHC -fno-warn-unused-imports       #-}
+
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Data.Monoid.Inf
--- Copyright   :  (c) 2012 diagrams-core team (see LICENSE)
+-- Copyright   :  (c) 2012-2015 diagrams-core team (see LICENSE)
 -- License     :  BSD-style (see LICENSE)
 -- Maintainer  :  diagrams-discuss@googlegroups.com
 --
--- Make semigroup under 'min' or 'max' into monoids by adjoining an
+-- Make semigroups under 'min' or 'max' into monoids by adjoining an
 -- element corresponding to infinity (positive or negative,
 -- respectively). These types are similar to @Option (Min a)@ and
 -- @Option (Max a)@ respectively, except that the 'Ord' instance
@@ -28,6 +31,7 @@ module Data.Monoid.Inf
        , posFinite, negFinite
        ) where
 
+import           Data.Data
 import           Data.Semigroup
 import           Prelude          hiding (maximum, minimum)
 import qualified Prelude          as P
@@ -39,7 +43,8 @@ data Pos
 data Neg
 
 data Inf p a = Infinity | Finite a
-  deriving (Eq, Show, Read, Functor, Foldable, Traversable)
+  deriving (Data, Typeable, Show, Read, Eq, Functor, Foldable,
+            Traversable)
 
 type PosInf a = Inf Pos a
 type NegInf a = Inf Neg a
